@@ -151,9 +151,9 @@ sub init {
     $self->{contexts}  = [];
     $self->{repo_maps} = {
         rakudo => [qw<rakudo rakudo>],
-        nqp    => [qw<perl6 nqp>],
+        nqp    => [qw<Raku nqp>],
         moar   => [qw<MoarVM MoarVM>],
-        roast  => [qw<perl6 roast>],
+        roast  => [qw<Raku roast>],
     };
 
     $self->{impls} = {};
@@ -498,7 +498,7 @@ sub configure_relocatability {
 sub configure_repo_urls {
     my $self = shift;
 
-    # Pre-cach repo urls to make them available for makefiles.
+    # Pre-cache repo urls to make them available for makefiles.
     for my $r ( keys %{ $self->{repo_maps} } ) {
         $self->repo_url( $r, action => 'pull' );
         $self->repo_url( $r, action => 'push' );
@@ -512,27 +512,30 @@ sub configure_commands {
     $config->{make} = $self->make_cmd;
 
     my $buf;
-    my $ok = run( command => [ $config->{make}, q<-v> ], buffer => \$buf );
-    unless ($ok) {
-        $ok = run( command => [ $config->{make}, q</?> ], buffer => \$buf );
-    }
-    if ( $buf =~ /^GNU Make/s ) {
-        $config->{make_family}       = 'gnu';
-        $config->{make_first_prereq} = '$<';
-        $config->{make_all_prereq}   = '$^';
-        $config->{make_pp_pfx} = '';    # make preprocessor directive prefix
-    }
-    elsif ( $buf =~ /Microsoft \(R\) Program Maintenance Utility/s ) {
-        $config->{make_family}       = 'nmake';
-        $config->{make_first_prereq} = '%s';
-        $config->{make_all_prereq}   = '$**';
-        $config->{make_pp_pfx}       = '!';
-    }
-    elsif ( $self->is_bsd && $config->{make} =~ /\bmake$/ ) {
-        $config->{make_family}       = 'bsd';
-        $config->{make_first_prereq} = '${>:[1]}';
-        $config->{make_all_prereq}   = '$>';
-        $config->{make_pp_pfx}       = '.';
+    for (my $retries = 50; $retries; $retries--) {
+        my $ok = run( command => [ $config->{make}, q<-v> ], buffer => \$buf );
+        unless ($ok) {
+            $ok = run( command => [ $config->{make}, q</?> ], buffer => \$buf );
+        }
+        if ( $buf =~ /^GNU Make/s ) {
+            $config->{make_family}       = 'gnu';
+            $config->{make_first_prereq} = '$<';
+            $config->{make_all_prereq}   = '$^';
+            $config->{make_pp_pfx} = '';    # make preprocessor directive prefix
+        }
+        elsif ( $buf =~ /Microsoft/s ) {
+            $config->{make_family}       = 'nmake';
+            $config->{make_first_prereq} = '%s';
+            $config->{make_all_prereq}   = '$**';
+            $config->{make_pp_pfx}       = '!';
+        }
+        elsif ( $self->is_bsd && $config->{make} =~ /\bmake$/ ) {
+            $config->{make_family}       = 'bsd';
+            $config->{make_first_prereq} = '${>:[1]}';
+            $config->{make_all_prereq}   = '$>';
+            $config->{make_pp_pfx}       = '.';
+        }
+        last if defined $config->{make_family};
     }
     unless ( defined $config->{make_family} ) {
         $self->sorry(
@@ -585,15 +588,15 @@ sub configure_misc {
     if ( $self->cfg('silent_build') eq 'on' ) {
         $config->{NOECHO_declaration} = <<NOECHO_DECL;
 NOECHO = @
-${make_pp_pfx}ifdef VERBOSE_BUILD 
-NOECHO = 
+${make_pp_pfx}ifdef VERBOSE_BUILD
+NOECHO =
 ${make_pp_pfx}endif
 NOECHO_DECL
     }
     else {
         $config->{NOECHO_declaration} = <<NOECHO_DECL;
-NOECHO = 
-${make_pp_pfx}ifdef SILENT_BUILD 
+NOECHO =
+${make_pp_pfx}ifdef SILENT_BUILD
 NOECHO = @
 ${make_pp_pfx}endif
 NOECHO_DECL
@@ -666,7 +669,7 @@ sub configure_from_options {
     for my $opt (
         qw<prefix rakudo-home nqp-home sdkroot sysroot github-user git-protocol
         rakudo-repo nqp-repo moar-repo roast-repo makefile-timing
-        relocatable reference>
+        relocatable git-cache-dir>
       )
     {
         ( my $ckey = $opt ) =~ s/-/_/g;
@@ -680,6 +683,12 @@ sub configure_from_options {
         $config->{"opt_$cf_var"} = $opt_val;
     }
 
+    if ( $self->{options}{'git-reference'} ) {
+        print "===WARNING!===\n";
+        print "The --git-reference option does not exist anymore.\n";
+        print "Consider using --git-cache-dir instead.\n";
+    }
+
     $config->{stagestats} = '--stagestats'
       if $self->{options}{'makefile-timing'};
 
@@ -1078,13 +1087,9 @@ sub fill_template_text {
 }
 
 sub reference_dir {
-    my $self      = shift;
-    my $reference = $self->cfg('reference');
-    for my $d (@_) {
-        my $dir = File::Spec->catdir( $reference, $d );
-        return $dir if -d $dir;
-    }
-    return '';
+    my ($self, $name) = @_;
+    my $git_cache_dir = $self->cfg('git_cache_dir');
+    return File::Spec->catdir( $git_cache_dir, $name );
 }
 
 sub git_checkout {
@@ -1096,18 +1101,34 @@ sub git_checkout {
     my $config  = $self->config;
     my $options = $self->{options};
     my $pwd     = cwd();
+    my $pullurl = $self->repo_url( $repo, action => 'pull' );
+    my $pushurl = $self->repo_url( $repo, action => 'push' );
 
+    # Clone / fetch git reference repo
+    if ( $config->{git_cache_dir} ) {
+        my $ref_dir =
+          $self->reference_dir( $self->{repo_maps}{$repo}[1] );
+        if ( !-d $ref_dir ) {
+            my @ref_args = ( 'git', 'clone', '--bare' );
+            push @ref_args, "--depth=$options->{'git-depth'}"
+              if $options->{'git-depth'};
+            push @ref_args, $pullurl, $ref_dir;
+            $self->msg("Cloning reference from $pullurl\n");
+            system_or_die(@ref_args);
+        }
+        else {
+            chdir($ref_dir);
+            system_or_die( 'git', 'fetch' );
+            chdir($pwd);
+        }
+    }
     # get an up-to-date repository
     if ( !-d $dir ) {
-        my ( $pullurl, $pushurl ) = (
-            $self->repo_url( $repo, action => 'pull' ),
-            $self->repo_url( $repo, action => 'push' ),
-        );
         my @args = ( 'git', 'clone' );
-        if ( $config->{reference} ) {
+        if ( $config->{git_cache_dir} ) {
             my $ref_dir =
-              $self->reference_dir( $self->{repo_maps}{$repo}[1], $dir );
-            die "Can't $repo repository directory in $config->{reference}"
+              $self->reference_dir( $self->{repo_maps}{$repo}[1] );
+            die "Can't find $repo reference directory in $config->{git_cache_dir}"
               unless $ref_dir;
             push @args, "--reference=$ref_dir";
         }
