@@ -1,6 +1,5 @@
 #define MVM_SHARED 1
 #include "moar.h"
-#include "container.h"
 
 #ifdef _WIN32
 #include <windows.h>
@@ -47,10 +46,9 @@ static MVMObject * get_thrower(MVMThreadContext *tc, MVMString *type) {
     return MVM_is_null(tc, ex_hash) ? ex_hash : MVM_repr_at_key_o(tc, ex_hash, type);
 }
 
-/* Initializes the Perl 6 extension ops. */
+/* Initializes the Raku extension ops. */
 static void p6init(MVMThreadContext *tc, MVMuint8 *cur_op) {
     if (!initialized) {
-        Rakudo_containers_setup(tc);
         initialized = 1;
 
         /* Strings. */
@@ -67,7 +65,7 @@ static void p6init(MVMThreadContext *tc, MVMuint8 *cur_op) {
     }
 }
 
-/* Boxing to Perl 6 types. */
+/* Boxing to Raku types. */
 static void discover_create(MVMThreadContext *tc, MVMSpeshGraph *g, MVMSpeshIns *ins, MVMObject *type) {
     MVMSpeshFacts *tfacts = MVM_spesh_get_facts(tc, g, ins->operands[0]);
     tfacts->flags |= MVM_SPESH_FACT_CONCRETE | MVM_SPESH_FACT_KNOWN_TYPE;
@@ -354,36 +352,6 @@ static void p6argsfordispatcher(MVMThreadContext *tc, MVMuint8 *cur_op) {
     MVM_exception_throw_adhoc(tc, "Could not find arguments for dispatcher");
 }
 
-static MVMuint8 s_p6decodelocaltime[] = {
-    MVM_operand_obj   | MVM_operand_write_reg,
-    MVM_operand_int64 | MVM_operand_read_reg
-};
-static void p6decodelocaltime(MVMThreadContext *tc, MVMuint8 *cur_op) {
-    MVMObject *result = MVM_repr_alloc_init(tc, tc->instance->boot_types.BOOTIntArray);
-    const time_t t = (time_t)GET_REG(tc, 2).i64;
-    struct tm tm;
-#ifdef _WIN32
-    tm = *localtime(&t);
-#else
-    localtime_r(&t, &tm);
-#endif
-
-    MVMROOT(tc, result, {
-        REPR(result)->pos_funcs.set_elems(tc, STABLE(result), result, OBJECT_BODY(result), 9);
-        MVM_repr_bind_pos_i(tc, result, 0, (&tm)->tm_sec);
-        MVM_repr_bind_pos_i(tc, result, 1, (&tm)->tm_min);
-        MVM_repr_bind_pos_i(tc, result, 2, (&tm)->tm_hour);
-        MVM_repr_bind_pos_i(tc, result, 3, (&tm)->tm_mday);
-        MVM_repr_bind_pos_i(tc, result, 4, (&tm)->tm_mon + 1);
-        MVM_repr_bind_pos_i(tc, result, 5, (&tm)->tm_year + 1900);
-        MVM_repr_bind_pos_i(tc, result, 6, (&tm)->tm_wday);
-        MVM_repr_bind_pos_i(tc, result, 7, (&tm)->tm_yday);
-        MVM_repr_bind_pos_i(tc, result, 8, (&tm)->tm_isdst);
-    });
-
-    GET_REG(tc, 0).o = result;
-}
-
 static MVMuint8 s_p6staticouter[] = {
     MVM_operand_obj | MVM_operand_write_reg,
     MVM_operand_obj | MVM_operand_read_reg
@@ -447,7 +415,6 @@ MVM_DLL_EXPORT void Rakudo_ops_init(MVMThreadContext *tc) {
     MVM_ext_register_extop(tc, "p6inpre", p6inpre, 1, s_p6inpre, NULL, NULL, 0);
     MVM_ext_register_extop(tc, "p6finddispatcher", p6finddispatcher, 2, s_p6finddispatcher, NULL, NULL, MVM_EXTOP_NO_JIT);
     MVM_ext_register_extop(tc, "p6argsfordispatcher", p6argsfordispatcher, 2, s_p6argsfordispatcher, NULL, NULL, 0);
-    MVM_ext_register_extop(tc, "p6decodelocaltime", p6decodelocaltime, 2, s_p6decodelocaltime, NULL, NULL, MVM_EXTOP_ALLOCATING);
     MVM_ext_register_extop(tc, "p6staticouter", p6staticouter, 2, s_p6staticouter, NULL, NULL, 0);
     MVM_ext_register_extop(tc, "p6invokeunder", p6invokeunder, 3, s_p6invokeunder, NULL, NULL, MVM_EXTOP_NO_JIT);
 }
