@@ -160,13 +160,18 @@ sub configure_refine_vars {
               || File::Spec->catdir( $config->{'prefix'}, 'share', 'perl6' )
         )
     );
+
+    $config->{static_rakudo_home} =
+      $config->{relocatable} eq 'reloc'
+      ? ''
+      : $config->{rakudo_home};
 }
 
 sub parse_lang_specs {
     my $self = shift;
 
     my $config = $self->{config};
-    my $tmpl   = 'PERL6_SPECS';
+    my $tmpl   = 'RAKU_SPECS';
     open my $sh, "<", $self->template_file_path( $tmpl, required => 1 )
       or self->sorry("Can't open $tmpl: $!");
 
@@ -213,7 +218,7 @@ sub parse_lang_specs {
         }
     }
 
-    $self->{perl6_specs} = \@specs;
+    $self->{raku_specs} = \@specs;
 
     close $sh;
 }
@@ -239,12 +244,12 @@ sub configure_misc {
     #    return \@elems;
     #};
 
-    #$self->{perl6_specs} = [
+    #$self->{raku_specs} = [
     #    map { $spec_line->($_) }
     #      grep { s/\s*#.*$//; length }
     #      split(
     #        /\n/s,
-    #        slurp( $self->template_file_path( 'PERL6_SPECS', required => 1, ) )
+    #        slurp( $self->template_file_path( 'RAKU_SPECS', required => 1, ) )
     #      )
     #];
 
@@ -319,7 +324,9 @@ sub configure_jvm_backend {
         );
         $config->{'nqp_classpath'} = $nqp_config->{'jvm::runtime.classpath'};
         $config->{'nqp::libdir'}   = $nqp_config->{'nqp::libdir'};
-        $config->{'j_runner'}      = $self->batch_file('perl6-j');
+        $config->{'j_runner'}      = $self->batch_file('rakudo-j');
+
+        $nqp_config->{static_nqp_home} = $nqp_config->{'nqp::static-nqp-home'};
     }
 }
 
@@ -344,14 +351,12 @@ sub configure_moar_backend {
 
     if ( $config->{relocatable} eq 'reloc' ) {
         $nqp_config->{static_nqp_home}           = '';
-        $nqp_config->{static_rakudo_home}        = '';
         $nqp_config->{static_nqp_home_define}    = '';
         $nqp_config->{static_rakudo_home_define} = '';
     }
     else {
         my $qchar = $config->{quote};
-        $nqp_config->{static_nqp_home}    = $nqp_config->{'nqp::nqp_home'};
-        $nqp_config->{static_rakudo_home} = $config->{rakudo_home};
+        $nqp_config->{static_nqp_home} = $nqp_config->{'nqp::static-nqp-home'};
         $nqp_config->{static_nqp_home_define} =
             '-DSTATIC_NQP_HOME='
           . $qchar
@@ -360,7 +365,7 @@ sub configure_moar_backend {
         $nqp_config->{static_rakudo_home_define} =
             '-DSTATIC_RAKUDO_HOME='
           . $qchar
-          . $self->c_escape_string( $nqp_config->{static_rakudo_home} )
+          . $self->c_escape_string( $config->{static_rakudo_home} )
           . $qchar;
     }
 
@@ -436,8 +441,8 @@ sub configure_js_backend {
     $config->{js_nqp} = $ijs->{bin};
     $config->{'perl6_runtime'} =
       File::Spec->rel2abs( $self->nfp('src/vm/js/perl6-runtime') );
-    $config->{'perl6_js_runner'} =
-      $self->batch_file( File::Spec->rel2abs('perl6-js') );
+    $config->{'rakudo_js_runner'} =
+      $self->batch_file( File::Spec->rel2abs('rakudo-js') );
 
     if ( $ijs->{ok} ) {
         $nqp_config = $ijs->{config};
@@ -454,6 +459,7 @@ sub configure_js_backend {
         'js',
         js_build_dir => File::Spec->catdir( $config->{base_dir}, qw<gen js> ),
         js_blib => File::Spec->catdir( $config->{base_dir}, "node_modules" ),
+        static_nqp_home => $nqp_config->{'nqp::static-nqp-home'},
     );
 }
 
@@ -532,9 +538,9 @@ sub clean_old_p6_libs {
 }
 
 # Returns all active language specification entries except for .c
-sub perl6_specs {
+sub raku_specs {
     my $self = shift;
-    return @{ $self->{perl6_specs} };
+    return @{ $self->{raku_specs} };
 }
 
 sub post_active_backends {
@@ -594,7 +600,6 @@ sub gen_nqp {
     my $prefix        = $config->{prefix};
     my $sdkroot       = $config->{'sdkroot'};
     my $startdir      = $config->{'base_dir'};
-    my $exe           = $config->{exe};
     my $nqp_want      = $config->{nqp_want};
     my $git_protocol  = $options->{'git-protocol'} // 'https';
     my @moar_options  = @{ $options->{'moar-option'} // [] };
@@ -612,6 +617,7 @@ sub gen_nqp {
     for my $b ( $self->active_backends ) {
         my $bconfig = $self->backend_config($b);
         my $postfix = $self->backend_abbr($b);
+        my $exe     = $b eq 'moar' ? $config->{exe} : $config->{bat};
         my $tpath   = File::Spec->catfile( $prefix, 'bin', "nqp-$postfix$exe" );
         my $bin     = $bconfig->{nqp_bin}
           || (
@@ -673,7 +679,7 @@ sub gen_nqp {
 
     # Append only the options we'd like to pass down to NQP's Configure.pl
     for my $opt (
-        qw<git-depth git-reference github-user nqp-repo moar-repo
+        qw<git-depth github-user nqp-repo moar-repo
         nqp-home relocatable ignore-errors with-moar silent-build
         force-rebuild>
       )
@@ -682,6 +688,10 @@ sub gen_nqp {
         push @cmd, $opt_str if $opt_str;
     }
 
+    push @cmd,
+      '--git-cache-dir=' . File::Spec->rel2abs( $options->{'git-cache-dir'} )
+      if $options->{'git-cache-dir'};
+
     push @cmd, "--backends=" . join( ",", $self->active_backends );
 
     if ( defined $gen_moar ) {
@@ -716,7 +726,7 @@ sub _specs_iterate {
 
     $self->not_in_context( specs => 'spec' );
 
-    for my $spec ( $cfg->perl6_specs ) {
+    for my $spec ( $cfg->raku_specs ) {
         my $spec_char   = $spec->[0];
         my $spec_subdir = "6.$spec_char";
         my %config      = (
@@ -751,6 +761,32 @@ sub _specs_iterate {
     }
 }
 
+# --- Utility methods
+
+{
+    my @all_sources;
+
+    sub _all_sources {
+        my $self     = shift;
+        my $base_dir = $self->cfg->cfg('base_dir');
+        unless (@all_sources) {
+            find(
+                sub {
+                    push @all_sources,
+                      File::Spec->abs2rel(
+                        File::Spec->catfile( $File::Find::dir, $_ ), $base_dir )
+                      if /\.(nqp|pm6)\z/;
+                },
+                File::Spec->catdir( $base_dir, "src" )
+            );
+            push @all_sources, 'gen/nqp-version';
+        }
+        return @all_sources;
+    }
+}
+
+# --- Macro implementations
+
 # for_specs(text)
 # Iterates over active backends and expands text in the context of each backend.
 sub _m_for_specs {
@@ -834,16 +870,18 @@ sub _m_for_langalias {
     return $out;
 }
 
+sub _m_source_digest_files {
+    my $self   = shift;
+    my $indent = " " x ( $self->cfg->{config}{filelist_indent} || 4 );
+    return join( " \\\n$indent", _all_sources($self) );
+}
+
 sub _m_source_digest {
     my $self = shift;
     my $sha  = Digest::SHA->new;
-    find(
-        sub {
-            $sha->addfile($_) if /\.(nqp|pm6)\z/;
-        },
-        File::Spec->catdir( $self->cfg->cfg('base_dir'), "src" )
-    );
-    $sha->addfile('gen/nqp-version');
+    foreach my $src ( _all_sources($self) ) {
+        $sha->addfile($src);
+    }
     return $sha->hexdigest;
 }
 
@@ -878,14 +916,15 @@ $text
 TPL
 }
 
-NQP::Macros->register_macro( 'for_specs',     \&_m_for_specs );
-NQP::Macros->register_macro( 'for_specmods',  \&_m_for_specmods );
-NQP::Macros->register_macro( 'for_toolchain', \&_m_for_toolchain );
-NQP::Macros->register_macro( 'for_langalias', \&_m_for_langalias );
-NQP::Macros->register_macro( 'source_digest', \&_m_source_digest );
-NQP::Macros->register_macro( 'gencat',        \&_m_gencat );
-NQP::Macros->register_macro( 'comp',          \&_m_comp, in_receipe => 1, );
-NQP::Macros->register_macro( 'comp_rr',       \&_m_comp_rr, in_receipe => 1, );
+NQP::Macros->register_macro( 'for_specs',           \&_m_for_specs );
+NQP::Macros->register_macro( 'for_specmods',        \&_m_for_specmods );
+NQP::Macros->register_macro( 'for_toolchain',       \&_m_for_toolchain );
+NQP::Macros->register_macro( 'for_langalias',       \&_m_for_langalias );
+NQP::Macros->register_macro( 'source_digest',       \&_m_source_digest );
+NQP::Macros->register_macro( 'source_digest_files', \&_m_source_digest_files );
+NQP::Macros->register_macro( 'gencat',              \&_m_gencat );
+NQP::Macros->register_macro( 'comp', \&_m_comp, in_receipe => 1, );
+NQP::Macros->register_macro( 'comp_rr', \&_m_comp_rr, in_receipe => 1, );
 
 1;
 
